#ifndef __AUTH_H__
#define __AUTH_H__

void GetUserLogin();

int  SetSmbAuthData(const char *server, const char *share,
	    const char *domain, const char *user, const char *password);

void smb_auth_fn(
		const char	*server,
		const char	*share,
		char		*wrkgrp, int wrkgrplen,
		char		*user,   int userlen,
		char		*passwd, int passwdlen);

void DeleteOldSmbAuthData(time_t change_time);

#endif	/* __AUTH_H__ */
